@@ -35,7 +35,7 @@ setMethod(".gframe",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE)
-              add(container, obj)
+              add(container, obj, expand=TRUE)
             }
             return(obj)
           })
