@@ -15,9 +15,9 @@ setMethod(".ggroup",
             if(is.null(spacing))
               spacing = 0
             if (horizontal)
-              group <- gtkHBoxNew(spacing=spacing)
+              group <- gtkHBoxNew(homogeneous=FALSE, spacing=spacing)
             else
-              group <- gtkVBoxNew(spacing=spacing)
+              group <- gtkVBoxNew(homogeneous=FALSE, spacing=spacing)
             
             ## let breath a little
             group$SetBorderWidth(2)
@@ -71,7 +71,18 @@ setMethod(".add",
 
             theArgs = list(...)
             expand = if(is.null(theArgs$expand)) FALSE else theArgs$expand
-  
+
+## This is an example of the pack_start() method.
+
+##   box.pack_start(child, expand, fill, padding)
+
+## box is the box you are packing the object into; the first argument is the child object to be packed. The objects will all be buttons for now, so we'll be packing buttons into boxes.
+
+## The expand argument to pack_start() and pack_end() controls whether the widgets are laid out in the box to fill in all the extra space in the box so the box is expanded to fill the area allotted to it (True); or the box is shrunk to just fit the widgets (False). Setting expand to False will allow you to do right and left justification of your widgets. Otherwise, they will all expand to fit into the box, and the same effect could be achieved by using only one of pack_start() or pack_end().
+
+## The fill argument to the pack methods control whether the extra space is allocated to the objects themselves (True), or as extra padding in the box around these objects (False). It only has an effect if the expand argument is also True.
+
+            
             getWidget(obj)$packStart(value, expand, TRUE, 0) # expand to fill if TRUE
           })
 
